@@ -47,9 +47,8 @@ def indent_prefix_first(text, prefix, indent="\t"):
 
 def now_playing(path) -> str:
     if path.startswith("http"):
-        return path
-
-    try:
+        text = path
+    else:
         text = (
             path
             + "\n"
@@ -59,11 +58,17 @@ def now_playing(path) -> str:
                 if path not in l
             )
         )
+
+    try:
+        text.encode()
         return text
     except UnicodeEncodeError:
-        return path
-    except Exception:
-        return "\n"
+        try:
+            text = path
+            text.encode()
+            return text
+        except Exception:
+            return "Could not encode file path as UTF-8"
 
 
 def source_now_playing(playing, source) -> str:
@@ -76,13 +81,23 @@ def playback_now() -> None:
     args = parse_args("now")
     playing = _now_playing(args)
 
-    if playing["mpv"]:
+    if playing["mpv"] and playing["catt"]:
         print(source_now_playing(playing, "mpv"))
         args.mpv.terminate()
-
-    if playing["catt"]:
         print(source_now_playing(playing, "catt"))
 
+    elif playing["mpv"]:
+        path = playing["mpv"]
+        print(now_playing(path))
+        args.mpv.terminate()
+
+    elif playing["catt"]:
+        path = playing["catt"]
+        print(now_playing(path))
+
+    else:
+        print("Nothing seems to be playing. You may need to specify --mpv-socket or --chromecast-device")
+
 
 def catt_stop(args) -> None:
     catt_device = []
